@@ -496,7 +496,7 @@ Define some classes to be used in the DAQ Filter Emulation.
 These are used to replicate the delay functions in the DAQ.
 '''
 spec = [('data', int32[:])]
-@numba.jitclass(spec)
+@jitclass(spec)
 class VarDelay:
 	def __init__(self,size):
 		self.data = np.zeros(size, dtype=int32)
@@ -507,7 +507,7 @@ class VarDelay:
 		return first_out
 
 spec = [('data', float32[:])]
-@numba.jitclass(spec)
+@jitclass(spec)
 class VarDelayFloat:
 	def __init__(self,size):
 		self.data = np.zeros(size, dtype=float32)
