@@ -218,6 +218,7 @@ class waveformFile:
 			#now add in the unix timestamp column if it's available
 			if self.getFileStartTime() is not None:
 				startTime = self.getFileStartTime()
+				print('startTime is :', startTime)
 				#now shift all of the FPGA times by this
 				self.__headers['unix timestamp'] = self.__headers['timestamp'] + startTime / (4E-9)
 		else:
@@ -380,7 +381,7 @@ class waveformFile:
 		If multiple files, it returns the first start time from the various files.
 		"""
 		if self.__startTime is not None and self.__hdf5:
-			return self.__startTime
+			return self.__startTime[0]
 		else:
 			headers = self.fileHeaders()
 			if len(headers) != 0:
